@@ -1,17 +1,16 @@
-;;; emacs-wiki.el --- Maintain a local Wiki using Emacs-friendly markup
+;;; emacs-wiki-httpd.el --- Provide support for serving Emacs Wiki pages
 
 ;; Copyright (C) 2001, 2002, 2003, 2004 John Wiegley (johnw AT gnu DOT org)
-;;
+
 ;; Emacs Lisp Archive Entry
-;; Filename: emacs-wiki.el
-;; Version: $Version$
+;; Filename: emacs-wiki-httpd.el
+;; Version: 2.66
 ;; Keywords: hypermedia
 ;; Author: John Wiegley (johnw AT gnu DOT org)
 ;;         Alex Schroeder (alex AT gnu DOT org)
-;; Maintainer: Sacha Chua <sacha@free.net.ph>
+;; Maintainer: Michael Olson (mwolson AT gnu DOT org)
 ;; Description: Maintain Emacs-friendly Wikis in a local directory
-;; Stable URL: http://sacha.free.net.ph/notebook/emacs/stable/emacs-wiki/
-;; Dev URL: http://sacha.free.net.ph/notebook/emacs/dev/emacs-wiki/
+;; URL: http://www.mwolson.org/projects/EmacsWiki.html
 ;; Compatibility: Emacs20, Emacs21, XEmacs21
 
 ;; This file is not part of GNU Emacs.
@@ -31,16 +30,12 @@
 ;; Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 ;; MA 02111-1307, USA.
 
-;;; Commentary:
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; Emacs Wiki HTTP Server (using httpd.el)
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;; Code:
-
 (require 'emacs-wiki)
 (require 'httpd)
 
@@ -353,8 +348,11 @@ in memory to speed up serving time."
            "Editing not allowed"
            (format "Editing Wiki page %s is not allowed" page))
         (while (and (null illegal)
-                    (setq pos (string-match "<\\s-*\\([^> \t]+\\)"
-                                            text pos)))
+                    (setq pos (string-match
+                               (concat "<\\s-*\\([^>"
+                                       emacs-wiki-regexp-blank
+                                       "]+\\)")
+                               text pos)))
           (setq pos (match-end 0))
           (if (assoc (match-string 1 text) emacs-wiki-dangerous-tags)
               (setq illegal (match-string 1 text))))
